@@ -8,7 +8,8 @@
 
 #include "kitinerary_export.h"
 
-#include <QVector>
+#include <QDateTime>
+#include <QList>
 
 #include <memory>
 
@@ -43,10 +44,10 @@ public:
     /** Create a File instance for the given i/o device. */
     explicit File(QIODevice *device);
     File(const File&) = delete;
-    File(File&&);
+    File(File&&) noexcept;
     ~File();
     File& operator=(const File&) = delete;
-    File& operator=(File&&);
+    File& operator=(File&&) noexcept;
 
     /** Sets the file name. Needs to be done before calling open(). */
     void setFileName(const QString &fileName);
@@ -55,29 +56,35 @@ public:
     /** Open the file for reading or writing. A filename needs to be set before calling this.
      *  All read/write operations require the file to be open as a precondition.
      */
-    bool open(OpenMode mode) const;
+    [[nodiscard]] bool open(OpenMode mode) const;
     /** Error message in case opening the file failed. */
-    QString errorString() const;
+    [[nodiscard]] QString errorString() const;
     /** Save and close the file. Automatically called from the dtor. */
     void close();
 
     /** Lists the identifiers of all reservations in this file. */
-    QVector<QString> reservations() const;
+    [[nodiscard]] QList<QString> reservations() const;
     /** Loads the reservation with the given identifier. */
-    QVariant reservation(const QString &resId) const;
+    [[nodiscard]] QVariant reservation(const QString &resId) const;
     /** Add a reservation to this file. A new unique identifier will be generated for the reservation. */
     void addReservation(const QVariant &res);
     /** Add a reservation to this file. The given identifier will be used. */
     void addReservation(const QString &id, const QVariant &res);
 
     /** Returns the pass identifier used in here for @p pass. */
-    static QString passId(const KPkPass::Pass *pass);
-    static QString passId(const QString &passTypeIdenfier, const QString &serialNumber);
+    [[nodiscard]] static QString passId(const KPkPass::Pass *pass);
+    [[nodiscard]] static QString passId(const QString &passTypeIdenfier, const QString &serialNumber);
+    /** Decodes an identifier returned by passId() again. */
+    struct PkPassIdentifier {
+        QString passTypeIdenfier;
+        QString serialNumber;
+    };
+    [[nodiscard]] static PkPassIdentifier decodePassId(QStringView);
 
     /** Lists all pkpass files in this file. */
-    QVector<QString> passes() const;
+    [[nodiscard]] QList<QString> passes() const;
     /** Pass data for the given pass id. */
-    QByteArray passData(const QString &passId) const;
+    [[nodiscard]] QByteArray passData(const QString &passId) const;
     /** Add a pkpass file to this file. */
     void addPass(KPkPass::Pass *pass, const QByteArray &rawData);
     /** Add a pkpass file with the given pass id. */
@@ -86,23 +93,31 @@ public:
     /** Makes sure the resulting file name is something that can safely be used without messing up the
      *  file system or archive structure.
      */
-    static QString normalizeDocumentFileName(const QString &name);
+    [[nodiscard]] static QString normalizeDocumentFileName(const QString &name);
 
     /** Lists all document identifiers. */
-    QVector<QString> documents() const;
+    [[nodiscard]] QList<QString> documents() const;
     /** Loads the document meta data of document @p id. */
-    QVariant documentInfo(const QString &id) const;
+    [[nodiscard]] QVariant documentInfo(const QString &id) const;
     /** Loads the content of document @p id. */
-    QByteArray documentData(const QString &id) const;
+    [[nodiscard]] QByteArray documentData(const QString &id) const;
     /** Adds a document and associated meta data to the file. */
     void addDocument(const QString &id, const QVariant &docInfo, const QByteArray &docData);
 
     /** List custom data in the given namespace. */
-    QVector<QString> listCustomData(const QString &scope) const;
+    [[nodiscard]] QList<QString> listCustomData(QStringView scope) const;
+    /** Returns @c true if custom data with the given id exists in @p scope. */
+    [[nodiscard]] bool hasCustomData(QStringView scope, const QString &id) const;
     /** Returns the custom data in the given namespace and with the given id. */
-    QByteArray customData(const QString &scope, const QString &id) const;
-    /** Adds a custom data element with identifier @p id in to namespace @p scope. */
-    void addCustomData(const QString &scope, const QString &id, const QByteArray &data);
+    [[nodiscard]] QByteArray customData(QStringView scope, const QString &id) const;
+    /** Returns the file time for the specified custom data.
+     *  @since 25.12
+     */
+    [[nodiscard]] QDateTime customDataFileTime(QStringView scope, const QString &id) const;
+    /** Adds a custom data element with identifier @p id in to namespace @p scope.
+     *  @param mtime Optional file time (since 25.12).
+     */
+    void addCustomData(QStringView scope, const QString &id, const QByteArray &data, const QDateTime &mtime = {});
 
 private:
     std::unique_ptr<FilePrivate> d;
