@@ -7,6 +7,8 @@
 #ifndef KITINERARY_FLIGHTUTIL_H
 #define KITINERARY_FLIGHTUTIL_H
 
+#include <chrono>
+
 namespace KItinerary {
 
 /** Utility functions for dealing with flights. */
@@ -15,7 +17,7 @@ namespace FlightUtil
 /** Check whether the given distance (in meters) can be covered by a flight
  *  in the given time (in seconds).
  */
-bool isPlausibleDistanceForDuration(int distance, int duration);
+bool isPlausibleDistanceForDuration(int distance, std::chrono::seconds duration);
 
 }
 
